#!/usr/bin/env python

"""
Moin serialiser support.

Copyright (C) 2017, 2018 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

class Serialiser:

    "General serialisation support."

    def __init__(self, out, formats=None):

        """
        Initialise the serialiser with an 'out' callable and an optional
        'formats' mapping from names to serialiser classes.
        """

        self.out = out
        self.formats = formats
        self.init()

    def init(self):

        "Initialisation method to be overridden by subclasses."

        pass

    def __repr__(self):
        return "%s(%r, %r)" % (self.__class__.__name__, self.out, self.formats)

def escape_attr(s):

    "Escape XML document attribute."

    return escape_text(s).replace("'", "&apos;").replace('"', "&quot;")

def escape_text(s):

    "Escape XML document text."

    return s.replace("&", "&amp;").replace("<", "&lt;").replace(">", "&gt;")

# vim: tabstop=4 expandtab shiftwidth=4
